import pytest
from a0 import guess_hangman

@pytest.fixture(scope="session", autouse=True)
def lexicon():
    lex = set()
    with open("lexicon.txt", "r") as lf:
        for word in lf:
            lex.add(word.strip())
    return lex

@pytest.mark.parametrize("word, max_attempts",
    [
        # in lexicon
        ("aim", 6),
        ("bike", 15),
        ("quiz", 12),
        ("syntax", 10),
        ("crawling", 11),
        ("counterproductive", 11),
        # out of lexicon
        ("arancina", 11),
        ("sicily", 17),
        ("dash", 18)
    ]
)
def test_hangman(lexicon, word, max_attempts):
    template = ['_'] * len(word)
    guessed = set()
    n = 0
    while ''.join(template) != word:
        n += 1
        if n > max_attempts: break
        ch = guess_hangman(template, lexicon, guessed)
        guessed.add(ch)

        matches = [i for i, x in enumerate(word) if x == ch]
        for i in matches:
            template[i] = ch
    assert n <= max_attempts

def test_imports():
    with open('a0.py', 'rt') as sf:
        for line in sf:
            assert not line.startswith('from'), "No imports allowed"
            if line.startswith('import'):
                assert line.strip() == "import argparse", "No imports allowed"

